==> de-BBBike-3.01.tgz: BBBike/BBBikeUtil.pm <==
# -*- perl -*-

#
# $Id: BBBikeUtil.pm,v 1.11 2000/08/09 06:59:24 eserte Exp $
# Author: Slaven Rezic
#
# Copyright (C) 1998 Slaven Rezic. All rights reserved.
# This package is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
#
# Mail: eserte@cs.tu-berlin.de
# WWW:  http://user.cs.tu-berlin.de/~eserte/
#

package BBBikeUtil;

require Exporter;
@ISA = qw(Exporter);

@EXPORT = qw(is_in_path catfile file_name_is_absolute
             int_round sqr s2hm s2ms h2hm m2km
	     pi deg2rad rad2deg schnittwinkel float_prec
	     cp850_iso iso_cp850 nil);

# REPO BEGIN
# REPO NAME is_in_path /home/e/eserte/src/repository 
# REPO MD5 ccab6618d5af7a1e314eb8e0e448ff2c
=head2 is_in_path($prog)

Return the pathname of $prog, if the program is in the PATH, or undef
otherwise.

DEPENDENCY: file_name_is_absolute

=cut

sub is_in_path {
    my($prog) = @_;
    return $prog if (file_name_is_absolute($prog) and -f $prog and -x $prog);
    require Config;
    my $sep = $Config::Config{'path_sep'} || ':';
    foreach (split(/$sep/o, $ENV{PATH})) {
	return "$_/$prog" if -x "$_/$prog";
    }
    undef;
}
# REPO END

sub catfile {
    my(@args) = @_;
    my $path;
    eval {
        require File::Spec;
        $path = File::Spec->catfile(@args);
    };
    if ($@) {
        $path = join("/", @args);
    }
    $path;
}

# REPO BEGIN
# REPO NAME file_name_is_absolute /home/e/eserte/src/repository 
# REPO MD5 47355e35bcf03edac9ea12c6f8fff9a3
=head2 file_name_is_absolute($file)

Return true, if supplied file name is absolute. This is only necessary
for older perls where File::Spec is not part of the system.

=cut

sub file_name_is_absolute {
    my $file = shift;
    my $r;
    eval {
        require File::Spec;
        $r = File::Spec->file_name_is_absolute($file);
    };
    if ($@) {
	if ($^O eq 'MSWin32') {
	    $r = ($file =~ m;^([a-z]:(/|\\)|\\\\|//);i);
	} else {
	    $r = ($file =~ m|^/|);
	}
    }
    $r;
}
# REPO END

sub int_round { int($_[0]+0.5) }

# Quadrat
sub sqr {
    $_[0] * $_[0];
}

# Sekunden in HH:MM-Schreibweise
sub s2hm {
    my $s = shift;
    sprintf "%d:%02d", $s/3600, ($s%3600)/60;
}

# Sekunden in MM:SS-Schreibweise
sub s2ms {
    my $s = shift;
    sprintf "%d:%02d", $s/60, $s%60;
}

# gebrochene Stunden in HH:MM-Schreibweise
sub h2hm {
    my $s = shift;
    sprintf "%d:%02d", $s, 60*($s - int($s));
}

# Meter in Kilometer umwandeln. $dig gibt die Anzahl der Nachkommastellen
# (Default: 1) an. Mit $sigdig (optional) kann die Anzahl der
# signifikaten Nachkommastellen angegeben werden (um Scheingenauigkeiten
# zu vermeiden): Beispiel m2km(1234,3,2) => 1.230. Dabei wird nicht gerundet.
sub m2km {
    my($s, $dig, $sigdig) = @_;
    return 0 unless $s =~ /\d/;
    $dig = 1 unless defined $dig;
    my $r = sprintf "%." . $dig . "f", $s/1000;
    if (defined $sigdig) {
	$r =~ s/\.(\d{$sigdig})(.*)/".$1" . ("0"x length($2))/e;
    }
    $r . " km";
}

# damit ich nicht Math::Trig und Math::Complex laden mu
sub pi ()   { 4 * atan2(1, 1) } # 3.141592653
sub deg2rad { ($_[0]*pi)/180 }
sub rad2deg { ($_[0]*180)/pi }

# Berechnet den Schnittwinkel
# Eingabe: $p1(x|y) und $p2(x|y): uere Punkte
#          $pm(x|y): Punkt in der Mitte (Schnittpunkt)
sub schnittwinkel {
    my($p1x, $p1y, $pmx, $pmy, $p2x, $p2y) = @_;
    require POSIX; # XXX fallback to Math::Trig, if necessary
    my $x1 = $pmx-$p1x;
    my $y1 = $pmy-$p1y;
    my $x2 = $p2x-$pmx;
    my $y2 = $p2y-$pmy;
    my $richtung = ($x1*$y2-$y1*$x2 > 0 ? 'l' : 'r');
    my $winkel = 0;
    eval {
	$winkel = POSIX::acos( ($x1*$x2+$y1*$y2) /
			       (sqrt(sqr($x1)+sqr($y1)) * 
				sqrt(sqr($x2)+sqr($y2)))
			     );
    };
    ($winkel, $richtung);
}

sub float_prec {
    my($float, $prec) = @_;
    no locale;
    sprintf "%.${prec}f", $float;
}

# Fhrt ein co auf die angegebene Datei $file aus.
# Rckgabewert: 1: OK, 0: bei "co" ist ein Fehler aufgetreten
# Exceptions: bei chdir
sub rcs_co {
    my $file = shift;
    require File::Basename;
    require Cwd;
    my $cwd = Cwd::cwd();
    my($f, $dir) = File::Basename::fileparse($file);
    chdir $dir or die "Kann kein chdir zum Verzeichnis $dir durchfhren: $!";
    system("co -l $f");
    my $ok = 1;
    if ($? != 0) {
	$ok = 0;
    }
    chdir $cwd;
    $ok;
}

# Zeichensatz-Konvertierungen

sub cp850_iso {
    my $s = shift;
    $s =~ tr/\204\224\201\216\231\232\341\202\370//;
    $s;
}

sub iso_cp850 {
    my $s = shift;
    $s =~ tr//\204\224\201\216\231\232\341\202\370/;
    $s;
}

# keine Zeichensatz-Konvertierung
sub nil { $_[0] }

1;

==> de-BBBike-3.03.tgz: BBBike/BBBikeUtil.pm <==
# -*- perl -*-

#
# $Id: BBBikeUtil.pm,v 1.13 2001/02/23 23:23:06 eserte Exp $
# Author: Slaven Rezic
#
# Copyright (C) 1998 Slaven Rezic. All rights reserved.
# This package is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
#
# Mail: eserte@cs.tu-berlin.de
# WWW:  http://user.cs.tu-berlin.de/~eserte/
#

package BBBikeUtil;

require Exporter;
@ISA = qw(Exporter);

@EXPORT = qw(is_in_path catfile file_name_is_absolute
             int_round sqr s2hm s2ms h2hm m2km
	     pi deg2rad rad2deg schnittwinkel float_prec
	     cp850_iso iso_cp850 nil
	     min max);

# REPO BEGIN
# REPO NAME is_in_path /home/e/eserte/src/repository 
# REPO MD5 ccab6618d5af7a1e314eb8e0e448ff2c
=head2 is_in_path($prog)

Return the pathname of $prog, if the program is in the PATH, or undef
otherwise.

DEPENDENCY: file_name_is_absolute

=cut

sub is_in_path {
    my($prog) = @_;
    return $prog if (file_name_is_absolute($prog) and -f $prog and -x $prog);
    require Config;
    my $sep = $Config::Config{'path_sep'} || ':';
    foreach (split(/$sep/o, $ENV{PATH})) {
	if ($^O eq 'MSWin32') {
	    return "$_\\$prog"
		if (-x "$_\\$prog.bat" ||
		    -x "$_\\$prog.com" ||
		    -x "$_\\$prog.exe");
	} else {
	    return "$_/$prog" if (-x "$_/$prog");
	}
    }
    undef;
}
# REPO END

sub catfile {
    my(@args) = @_;
    my $path;
    eval {
        require File::Spec;
        $path = File::Spec->catfile(@args);
    };
    if ($@) {
        $path = join("/", @args);
    }
    $path;
}

# REPO BEGIN
# REPO NAME file_name_is_absolute /home/e/eserte/src/repository 
# REPO MD5 47355e35bcf03edac9ea12c6f8fff9a3
=head2 file_name_is_absolute($file)

Return true, if supplied file name is absolute. This is only necessary
for older perls where File::Spec is not part of the system.

=cut

sub file_name_is_absolute {
    my $file = shift;
    my $r;
    eval {
        require File::Spec;
        $r = File::Spec->file_name_is_absolute($file);
    };
    if ($@) {
	if ($^O eq 'MSWin32') {
	    $r = ($file =~ m;^([a-z]:(/|\\)|\\\\|//);i);
	} else {
	    $r = ($file =~ m|^/|);
	}
    }
    $r;
}
# REPO END

sub int_round { int($_[0]+0.5) }

# Quadrat
sub sqr {
    $_[0] * $_[0];
}

# Sekunden in HH:MM-Schreibweise
sub s2hm {
    my $s = shift;
    sprintf "%d:%02d", $s/3600, ($s%3600)/60;
}

# Sekunden in MM:SS-Schreibweise
sub s2ms {
    my $s = shift;
    sprintf "%d:%02d", $s/60, $s%60;
}

# gebrochene Stunden in HH:MM-Schreibweise
sub h2hm {
    my $s = shift;
    sprintf "%d:%02d", $s, 60*($s - int($s));
}

# Meter in Kilometer umwandeln. $dig gibt die Anzahl der Nachkommastellen
# (Default: 1) an. Mit $sigdig (optional) kann die Anzahl der
# signifikaten Nachkommastellen angegeben werden (um Scheingenauigkeiten
# zu vermeiden): Beispiel m2km(1234,3,2) => 1.230. Dabei wird nicht gerundet.
sub m2km {
    my($s, $dig, $sigdig) = @_;
    return 0 unless $s =~ /\d/;
    $dig = 1 unless defined $dig;
    my $r = sprintf "%." . $dig . "f", $s/1000;
    if (defined $sigdig) {
	$r =~ s/\.(\d{$sigdig})(.*)/".$1" . ("0"x length($2))/e;
    }
    $r . " km";
}

# damit ich nicht Math::Trig und Math::Complex laden mu
sub pi ()   { 4 * atan2(1, 1) } # 3.141592653
sub deg2rad { ($_[0]*pi)/180 }
sub rad2deg { ($_[0]*180)/pi }

# Berechnet den Schnittwinkel
# Eingabe: $p1(x|y) und $p2(x|y): uere Punkte
#          $pm(x|y): Punkt in der Mitte (Schnittpunkt)
sub schnittwinkel {
    my($p1x, $p1y, $pmx, $pmy, $p2x, $p2y) = @_;
    require POSIX; # XXX fallback to Math::Trig, if necessary
    my $x1 = $pmx-$p1x;
    my $y1 = $pmy-$p1y;
    my $x2 = $p2x-$pmx;
    my $y2 = $p2y-$pmy;
    my $richtung = ($x1*$y2-$y1*$x2 > 0 ? 'l' : 'r');
    my $winkel = 0;
    eval {
	$winkel = POSIX::acos( ($x1*$x2+$y1*$y2) /
			       (sqrt(sqr($x1)+sqr($y1)) * 
				sqrt(sqr($x2)+sqr($y2)))
			     );
    };
    ($winkel, $richtung);
}

sub float_prec {
    my($float, $prec) = @_;
    no locale;
    sprintf "%.${prec}f", $float;
}

# Fhrt ein co auf die angegebene Datei $file aus.
# Rckgabewert: 1: OK, 0: bei "co" ist ein Fehler aufgetreten
# Exceptions: bei chdir
sub rcs_co {
    my $file = shift;
    require File::Basename;
    require Cwd;
    my $cwd = Cwd::cwd();
    my($f, $dir) = File::Basename::fileparse($file);
    chdir $dir or die "Kann kein chdir zum Verzeichnis $dir durchfhren: $!";
    system("co -l $f");
    my $ok = 1;
    if ($? != 0) {
	$ok = 0;
    }
    chdir $cwd;
    $ok;
}

# Zeichensatz-Konvertierungen

sub cp850_iso {
    my $s = shift;
    $s =~ tr/\204\224\201\216\231\232\341\202\370//;
    $s;
}

sub iso_cp850 {
    my $s = shift;
    $s =~ tr//\204\224\201\216\231\232\341\202\370/;
    $s;
}

# keine Zeichensatz-Konvertierung
sub nil { $_[0] }

sub min {
    my $min;
    for (@_) {
	$min = $_ if (!defined $min || $min > $_);
    }
    $min;
}

sub max {
    my $max;
    for (@_) {
	$max = $_ if (!defined $max || $max < $_);
    }
    $max;
}

1;
